import { RefObject } from "react";
import { MotionValuesMap } from "../motion/utils/use-motion-values";
import { AnimationControls } from "../motion";
declare type DragDirection = "x" | "y";
export declare type Constraints = {
    left?: number;
    right?: number;
    top?: number;
    bottom?: number;
};
export declare type Overdrag = boolean | number;
export interface DraggableProps {
    /**
     * Enable dragging for this element
     *
     * Set "x" or "y" to only drag in a specific direction
     * Set "lockDirection" to lock dragging into the initial direction
     *  @default false
     */
    dragEnabled?: boolean | DragDirection | "lockDirection";
    /**
     * Disable global drag locking
     * When using nested dragging, setting this to true will enable parents to also drag
     * @default false
     */
    dragPropagation?: boolean;
    /**
     * Apply constraints to dragging
     * @default false
     */
    dragConstraints?: Constraints;
    /**
     * Allow "dragElasticging" beyond the drag constraints
     * @default false
     */
    dragElastic?: Overdrag;
    /**
     * Allow smooth scrolling
     * @default false
     */
    dragMomentum?: boolean;
    onDragStart?: (e: MouseEvent | TouchEvent) => void;
    onDragEnd?: (e: MouseEvent | TouchEvent) => void;
    onDirectionLock?: (axis: string) => void;
}
export declare function useDraggable({ dragEnabled, dragPropagation, dragConstraints, dragElastic, dragMomentum, onDragStart, onDragEnd, onDirectionLock, }: DraggableProps, ref: RefObject<Element | null>, values: MotionValuesMap, controls: AnimationControls): void;
export {};
